.. _hubugs-label:

.. module:: hubugs

``hubugs``
==========

.. warning::

   I don’t really use GitHub anymore, so this package is somewhat orphaned.  It
   should still work *and* I will fix bugs when they’re pointed out, but
   ``hubugs`` is frankly quite a low priority for me.


:mod:`hubugs` is a very simple client for working with `GitHub’s issue
tracker`_ from the command line.

It is written in Python_, and works with Python 3.5 and newer.  :mod:`hubugs` is
released under the `GPL v3`_

:Git repository:  https://github.com/JNRowe/hubugs/
:Issue tracker:  https://github.com/JNRowe/hubugs/issues/
:Contributors:  https://github.com/JNRowe/hubugs/contributors/

Contents
--------

.. toctree::
   :maxdepth: 2

   background
   install
   config
   usage
   templates
   hubugs manpage <hubugs.1>
   faq
   alternatives
   release
   todo
   api/index
   appendix
   glossary

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _Github’s issue tracker: http://github.com/blog/411-github-issue-tracker
.. _Python: http://www.python.org/
.. _GPL v3: http://www.gnu.org/licenses/
